Lattices |travis| |appveyor| |codecov| |readthedocs|
====================================================

``Lattices`` is a package for the construction of lattices from a set of nodes and an ordering
relation.

Drawing
-------

Lattices optionally utilizes `nxpd` to draw a lattice. This package is somewhat out of date at this
point, and you install a modified version:

.. code-block:: bash

  pip install git+https://git@github.com/chebee7i/nxpd.git@refs/pull/15/merge#egg=nxpd



.. |travis| image:: https://travis-ci.org/Autoplectic/lattices.svg?branch=master
   :target: https://travis-ci.org/Autoplectic/lattices
   :alt: build status

.. |appveyor| image:: https://ci.appveyor.com/api/projects/status/to2kso5s9a07ehbe?svg=true
   :target: https://ci.appveyor.com/project/Autoplectic/lattices/branch/master
   :alt: build status

.. |codecov| image:: https://codecov.io/gh/Autoplectic/lattices/branch/master/graph/badge.svg
  :target: https://codecov.io/gh/Autoplectic/lattices
  :alt: test coverage

.. |readthedocs| image:: https://readthedocs.org/projects/lattices/badge/?version=latest
  :target: https://lattices.readthedocs.io/en/latest/?badge=latest
  :alt: documentation status
